# urlgen

## Usage
```
urlgen <URL>
```

## Available sites
MEGAUPLOAD
UploadHaven
Google Drive
Zippyshare
MediaFire
uploader.jp
  `--password <password>` to specify password.
  If not specified a prompt will be opened.
